@@ -64,7 +64,9 @@ class NotificationEventSerializer(serializers.ModelSerializer):
         model = NotificationEvent
         fields = ['id', 'title', 'smtp_provider', 'smtp_provider_detail', 'template', 'template_detail', 'subject',
                   'content', 'notification_event_type', 'notification_event_type_display', 'notification_groups',
-                  'notification_groups_detail', 'attachments', 'recipients']
+                  'notification_groups_detail', 'attachments', 'recipients', 'is_sent', 'sent_time', 'created_time',
+                  'updated_time']
+        read_only_fields = ['is_sent', 'sent_time', 'created_time', 'updated_time']
 
         extra_kwargs = {
             'template': {'write_only': True, 'allow_null': True},
@@ -131,6 +133,41 @@ class NotificationEventSerializer(serializers.ModelSerializer):
         return attrs
 
 
+class NotificationEventDetailSerializer(serializers.ModelSerializer):
+    attachments = AttachmentSerializer(many=True, required=False)
+    template_detail = EmailTemplateSerializer(source='template', read_only=True)
+    smtp_provider_detail = MinimalSmtpProviderSerializer(source='smtp_provider', read_only=True)
+    notification_event_type_display = serializers.CharField(source='get_notification_event_type_display',
+                                                            read_only=True)
+    notification_groups_detail = MinimalNotificationGroupSerializer(source='notification_groups', many=True,
+                                                                    read_only=True)
+    recipients = serializers.PrimaryKeyRelatedField(many=True, queryset=User.objects.filter(is_active=True),
+                                                    required=False)
+    sent_status_count = serializers.IntegerField(read_only=True, default=0)
+    pending_status_count = serializers.IntegerField(read_only=True, default=0)
+    failed_status_count = serializers.IntegerField(read_only=True, default=0)
+    bounce_status_count = serializers.IntegerField(read_only=True, default=0)
+    complaint_status_count = serializers.IntegerField(read_only=True, default=0)
+    delivery_status_count = serializers.IntegerField(read_only=True, default=0)
+    amazon_send_status_count = serializers.IntegerField(read_only=True, default=0)
+    reject_status_count = serializers.IntegerField(read_only=True, default=0)
+    open_status_count = serializers.IntegerField(read_only=True, default=0)
+    click_status_count = serializers.IntegerField(read_only=True, default=0)
+    rendering_failure_status_count = serializers.IntegerField(read_only=True, default=0)
+    delivery_delay_status_count = serializers.IntegerField(read_only=True, default=0)
+    subscription_status_count = serializers.IntegerField(read_only=True, default=0)
+
+    class Meta:
+        model = NotificationEvent
+        fields = ['id', 'title', 'smtp_provider_detail', 'template_detail', 'subject', 'content',
+                  'notification_event_type', 'notification_event_type_display', 'notification_groups_detail',
+                  'attachments', 'recipients', 'is_sent', 'sent_time', 'created_time', 'updated_time',
+                  'sent_status_count', 'pending_status_count', 'failed_status_count', 'bounce_status_count',
+                  'complaint_status_count', 'delivery_status_count', 'amazon_send_status_count', 'reject_status_count',
+                  'open_status_count', 'click_status_count', 'rendering_failure_status_count',
+                  'delivery_delay_status_count', 'subscription_status_count']
+
+
 class MinimalNotificationEventSerializer(serializers.ModelSerializer):
     template_detail = EmailTemplateSerializer(source='template', read_only=True)
     attachments = AttachmentSerializer(many=True, read_only=True)
@@ -140,7 +177,8 @@ class MinimalNotificationEventSerializer(serializers.ModelSerializer):
     class Meta:
         model = NotificationEvent
         fields = ['id', 'title', 'subject', 'content', 'notification_event_type', 'notification_event_type_display',
-                  'template_detail', 'attachments']
+                  'template_detail', 'attachments', 'is_sent', 'sent_time', 'created_time', 'updated_time']
+        read_only_fields = ['is_sent', 'sent_time', 'created_time', 'updated_time']
 
 
 class OutgoingMessageSerializer(serializers.ModelSerializer):
