@@ -1,5 +1,6 @@
 from django.conf import settings
-from django.db.models import Q
+from django.db.models import Q, Count
+from django.utils import timezone
 from django_filters.rest_framework import DjangoFilterBackend
 from rest_framework import viewsets, mixins, filters
 from rest_framework.decorators import action
@@ -12,7 +13,7 @@ from rest_framework_simplejwt.authentication import JWTAuthentication
 from notification_system.api.serializers import (NotificationEventSerializer, EmailTemplateSerializer,
                                                  OutgoingMessageSerializer, MinimalNotificationGroupSerializer,
                                                  MinimalSmtpProviderSerializer, OutgoingMessageNotificationSerializer,
-                                                 MediaSerializer)
+                                                 MediaSerializer, NotificationEventDetailSerializer)
 from notification_system.models import (NotificationEvent, EmailTemplate, OutgoingMessage, NotificationGroup,
                                         SmtpProvider, Media)
 from notification_system.notification_delivery import broadcast_event_messages_to_recipients
@@ -37,13 +38,67 @@ class NotificationEventViewSet(mixins.ListModelMixin,
     pagination_class = CustomLimitOffsetPagination
     filter_backends = [DjangoFilterBackend, filters.OrderingFilter]
     ordering_fields = ['id']
-    filter_fields = ['notification_groups', 'recipients', 'notification_event_type']
+    filter_fields = ['notification_groups', 'recipients', 'notification_event_type', 'is_sent']
 
     def get_queryset(self):
+        filter_params = {
+            'broadcast_message': {'is_sent': False},
+        }.get(self.action, dict())
+
+        annotate_params = {
+            'retrieve': {
+                'sent_status_count': Count('outgoing_messages',
+                                           filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_SENT)),
+                'pending_status_count': Count('outgoing_messages',
+                                              filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_PENDING)),
+                'failed_status_count': Count('outgoing_messages',
+                                             filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_FAILED)),
+                'bounce_status_count': Count('outgoing_messages',
+                                             filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_BOUNCE)),
+                'complaint_status_count':
+                    Count('outgoing_messages',
+                          filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_COMPLAINT)),
+
+                'delivery_status_count':
+                    Count('outgoing_messages',
+                          filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_DELIVERY)),
+
+                'amazon_send_status_count':
+                    Count('outgoing_messages', filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_SEND)),
+
+                'reject_status_count': Count('outgoing_messages',
+                                             filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_REJECT)),
+
+                'open_status_count': Count('outgoing_messages',
+                                           filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_OPEN)),
+
+                'click_status_count': Count('outgoing_messages',
+                                            filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_CLICK)),
+
+                'rendering_failure_status_count':
+                    Count('outgoing_messages',
+                          filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_RENDERING_FAILURE)),
+
+                'delivery_delay_status_count':
+                    Count('outgoing_messages',
+                          filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_DELIVERY_DELAY)),
+
+                'subscription_status_count':
+                    Count('outgoing_messages',
+                          filter=Q(outgoing_messages__status=OutgoingMessage.STATUS_AMAZON_SUBSCRIPTION)),
+            }
+        }.get(self.action, dict())
+
         queryset = super().get_queryset()
         queryset = queryset.prefetch_related('attachments', 'notification_groups__members', 'notification_groups')
         queryset = queryset.prefetch_related('recipients').select_related('smtp_provider', 'template')
-        return queryset.filter(owner=self.request.user)
+        return queryset.filter(owner=self.request.user, **filter_params).annotate(**annotate_params)
+
+    def get_serializer_class(self):
+        return {
+            'retrieve': NotificationEventDetailSerializer,
+
+        }.get(self.action, self.serializer_class)
 
     def perform_create(self, serializer):
         serializer.save(owner=self.request.user)
@@ -52,6 +107,10 @@ class NotificationEventViewSet(mixins.ListModelMixin,
     def broadcast_message(self, request, pk=None):
         instance = self.get_object()
         broadcast_event_messages_to_recipients(event_message_id=instance.id)
+        instance.is_sent = True
+        instance.sent_time = timezone.now()
+        instance.save(update_fields=['is_sent', 'sent_time'])
+
         return Response(status=200)
 
 
