@@ -113,6 +113,8 @@ class NotificationEvent(BaseModel):
     recipients = models.ManyToManyField(to=User, verbose_name=_('members'), related_name='recipients', blank=True)
     subject = models.CharField(verbose_name=_('subject'), max_length=255, blank=True)
     content = models.TextField(verbose_name=_('content'), blank=True)
+    sent_time = models.DateTimeField(verbose_name=_('sent time'), null=True, blank=True)
+    is_sent = models.BooleanField(verbose_name=_('is sent?'), default=False)
     is_active = models.BooleanField(verbose_name=_('is active?'), default=True)
 
     objects = models.Manager()
